@@ -363,9 +363,7 @@ class CbsClient(AbstractClient):
 
 
     def DescribeDiskOperationLogs(self, request):
-        """本接口（DescribeDiskOperationLogs）用于查询云盘操作日志列表。
-
-        可根据云盘ID过滤。云盘ID形如：disk-a1kmcp13。
+        """查询云盘操作日志功能已迁移至LookUpEvents接口（https://cloud.tencent.com/document/product/629/12359），本接口（DescribeDiskOperationLogs）即将下线，后续不再提供调用，请知悉。
 
         :param request: Request instance for DescribeDiskOperationLogs.
         :type request: :class:`tencentcloud.cbs.v20170312.models.DescribeDiskOperationLogsRequest`
@@ -392,6 +390,37 @@ class CbsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDiskStoragePool(self, request):
+        """本接口（DescribeDiskStoragePool）查询用户的云硬盘独享集群列表。
+
+        * 可以根据独享集群ID(CdcId)、集群区域名(zone)类型等信息来查询和过滤云硬盘独享集群详细信息，不同条件之间为与(AND)的关系，过滤信息详细请见过滤器`Filter`。
+        * 如果参数为空，返回当前用户一定数量（`Limit`所指定的数量，默认为20）的云硬盘独享集群列表。
+
+        :param request: Request instance for DescribeDiskStoragePool.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.DescribeDiskStoragePoolRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.DescribeDiskStoragePoolResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDiskStoragePool", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDiskStoragePoolResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDisks(self, request):
         """本接口（DescribeDisks）用于查询云硬盘列表。
 
@@ -601,6 +630,38 @@ class CbsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def InitializeDisks(self, request):
+        """重新初始化云硬盘至云硬盘初始创建时的状态。使用云硬盘的重新初始化功能时需要注意以下4点：
+        1. 如果云硬盘是由快照创建的，则重新初始化会通过此快照重新回滚此云硬盘，即将云硬盘恢复为与快照一致的状态；
+        2. 如果云硬盘不是通过快照创建的，则重新初始化会清空此云硬盘的数据；请在重新初始化云硬盘前检查并备份必要的数据；
+        3. 当前仅未挂载的、非共享属性的数据盘云硬盘支持重新初始化；
+        4. 当创建此云硬盘的原始快照被删除时，不再支持重新初始化此云硬盘。
+
+        :param request: Request instance for InitializeDisks.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.InitializeDisksRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.InitializeDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("InitializeDisks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.InitializeDisksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def InquirePriceModifyDiskExtraPerformance(self, request):
         """本接口（InquirePriceModifyDiskExtraPerformance）用于调整云硬盘额外性能询价。
 
